ElixirDashboard.PerformanceMonitor.TelemetryHandler (ElixirDashboard v0.2.0)
View SourceAttaches to Phoenix and Ecto telemetry events to capture performance metrics.
Configuration
You can configure the thresholds for what gets captured:
config :elixir_dashboard,
endpoint_threshold_ms: 100,
query_threshold_ms: 50,
repo_prefixes: [[:my_app, :repo]]Usage
In your application.ex:
if Mix.env() == :dev do
ElixirDashboard.PerformanceMonitor.TelemetryHandler.attach()
end